pub trait Scope<S, V>where
Self: Sized,{
// Required method
fn scope(symb: Symb<S>, ctx: &Ctx<Self, V>) -> Self;
// Provided method
fn go(symb: Symb<S>, ctx: &Ctx<Self, V>) -> Term<Self, V> { ... }
}Expand description
Convert a symbol to a given type of atoms.
Required Methods
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl<S: Borrow<str> + Into<C> + Eq, C, V: Borrow<str>> Scope<S, V> for Atom<Symb<C>>
Distinguish symbols into constants and variables.
impl<S: Into<S2>, S2, V> Scope<S, V> for Symb<S2>
The trivial scoper, mapping symbols to something they can be trivially converted to (including themselves).